npm - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# npm

Some optional parts of Betty use third-party JavaScript packages to help build your site.

If you installed Betty via pip or from source, you must also install Node.js, which includes npm. Afterwards, ensure `npm` is in your `PATH`, e.g. that `npm` can be run in a terminal from anywhere.